# coding: utf-8

# flake8: noqa
"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from verity471.models.activity import Activity
from verity471.models.activity_location import ActivityLocation
from verity471.models.activity_response import ActivityResponse
from verity471.models.actor import Actor
from verity471.models.actor_object import ActorObject
from verity471.models.actor_stream_page import ActorStreamPage
from verity471.models.actor_subject_of_report import ActorSubjectOfReport
from verity471.models.admiralty_code import AdmiraltyCode
from verity471.models.all_malware_profiles import AllMalwareProfiles
from verity471.models.assessment import Assessment
from verity471.models.attachment_classification import AttachmentClassification
from verity471.models.attachment_data import AttachmentData
from verity471.models.author_actor1 import AuthorActor1
from verity471.models.bad_request import BadRequest
from verity471.models.bot_settings import BotSettings
from verity471.models.breach_alert_by_id_response import BreachAlertByIdResponse
from verity471.models.breach_alert_response import BreachAlertResponse
from verity471.models.breach_alerts_response_stream import BreachAlertsResponseStream
from verity471.models.chat_message_stream import ChatMessageStream
from verity471.models.chat_messages_streaming_page import ChatMessagesStreamingPage
from verity471.models.chat_room_message_stream import ChatRoomMessageStream
from verity471.models.chat_server_type import ChatServerType
from verity471.models.chat_server_type_stream import ChatServerTypeStream
from verity471.models.classification import Classification
from verity471.models.classification_response import ClassificationResponse
from verity471.models.confidence import Confidence
from verity471.models.confidence_level import ConfidenceLevel
from verity471.models.conflict import Conflict
from verity471.models.controller_url import ControllerUrl
from verity471.models.country_profile_response import CountryProfileResponse
from verity471.models.cred_credential_set_response import CredCredentialSetResponse
from verity471.models.cred_data_response import CredDataResponse
from verity471.models.cred_password_complexity_response import CredPasswordComplexityResponse
from verity471.models.cred_password_response import CredPasswordResponse
from verity471.models.cred_set_accessed_url_data_response import CredSetAccessedUrlDataResponse
from verity471.models.cred_set_data_response import CredSetDataResponse
from verity471.models.cred_set_statistics_response import CredSetStatisticsResponse
from verity471.models.cred_statistics_response import CredStatisticsResponse
from verity471.models.credential_occurrence_cred_response import CredentialOccurrenceCredResponse
from verity471.models.credential_occurrence_data_response import CredentialOccurrenceDataResponse
from verity471.models.cve_source import CveSource
from verity471.models.cvss import Cvss
from verity471.models.data_leak_site_file_listing_url import DataLeakSiteFileListingUrl
from verity471.models.data_leak_site_post1 import DataLeakSitePost1
from verity471.models.data_leak_site_post_item import DataLeakSitePostItem
from verity471.models.data_leak_site_post_thread import DataLeakSitePostThread
from verity471.models.data_leak_site_post_website import DataLeakSitePostWebsite
from verity471.models.data_leak_site_posts_streaming_page import DataLeakSitePostsStreamingPage
from verity471.models.encryption import Encryption
from verity471.models.entities import Entities
from verity471.models.entity import Entity
from verity471.models.entity_item import EntityItem
from verity471.models.entity_stream_page import EntityStreamPage
from verity471.models.entity_type import EntityType
from verity471.models.error_response import ErrorResponse
from verity471.models.error_response_girs import ErrorResponseGirs
from verity471.models.event_controller import EventController
from verity471.models.event_data import EventData
from verity471.models.event_tag import EventTag
from verity471.models.events_stream import EventsStream
from verity471.models.exploit_status import ExploitStatus
from verity471.models.file import File
from verity471.models.fintel_report_sub_type import FintelReportSubType
from verity471.models.fintel_reports_response_stream import FintelReportsResponseStream
from verity471.models.fintel_response import FintelResponse
from verity471.models.forbidden import Forbidden
from verity471.models.forum import Forum
from verity471.models.forum_object import ForumObject
from verity471.models.forums_posts_streaming_page import ForumsPostsStreamingPage
from verity471.models.forums_private_messages_streaming_page import ForumsPrivateMessagesStreamingPage
from verity471.models.forums_response1 import ForumsResponse1
from verity471.models.gir import GIR
from verity471.models.geo_ip import GeoIp
from verity471.models.geo_ip_observables import GeoIpObservables
from verity471.models.geopol_report_details_response import GeopolReportDetailsResponse
from verity471.models.geopol_report_sub_type import GeopolReportSubType
from verity471.models.geopol_reports_response_stream import GeopolReportsResponseStream
from verity471.models.get_cred_occurrence_response import GetCredOccurrenceResponse
from verity471.models.get_cred_occurrence_response_stream import GetCredOccurrenceResponseStream
from verity471.models.get_cred_response import GetCredResponse
from verity471.models.get_cred_response_stream import GetCredResponseStream
from verity471.models.get_cred_set_accessed_url_response import GetCredSetAccessedUrlResponse
from verity471.models.get_cred_set_accessed_url_response_stream import GetCredSetAccessedUrlResponseStream
from verity471.models.get_cred_set_response import GetCredSetResponse
from verity471.models.get_cred_set_response_stream import GetCredSetResponseStream
from verity471.models.get_watcher_group_response import GetWatcherGroupResponse
from verity471.models.get_watcher_group_response_wrapper import GetWatcherGroupResponseWrapper
from verity471.models.get_watcher_response import GetWatcherResponse
from verity471.models.get_watcher_response_wrapper import GetWatcherResponseWrapper
from verity471.models.gir_tree import GirTree
from verity471.models.girs_response import GirsResponse
from verity471.models.girs_tree_response import GirsTreeResponse
from verity471.models.highlight import Highlight
from verity471.models.highlight_watchers import HighlightWatchers
from verity471.models.href import Href
from verity471.models.im_server import ImServer
from verity471.models.image_type import ImageType
from verity471.models.indicator_data import IndicatorData
from verity471.models.indicators_stream import IndicatorsStream
from verity471.models.industries import Industries
from verity471.models.info_report_response import InfoReportResponse
from verity471.models.info_reports_response_stream import InfoReportsResponseStream
from verity471.models.info_stealer_response_option import InfoStealerResponseOption
from verity471.models.info_stealer_response_set import InfoStealerResponseSet
from verity471.models.integrations_event import IntegrationsEvent
from verity471.models.integrations_indicator import IntegrationsIndicator
from verity471.models.intelligence_estimate_response import IntelligenceEstimateResponse
from verity471.models.interest_level import InterestLevel
from verity471.models.internal_server_error import InternalServerError
from verity471.models.ipv4 import Ipv4
from verity471.models.isp import Isp
from verity471.models.isp_data import IspData
from verity471.models.kill_chain_phase import KillChainPhase
from verity471.models.link import Link
from verity471.models.link1 import Link1
from verity471.models.links import Links
from verity471.models.links_source import LinksSource
from verity471.models.links_watchers import LinksWatchers
from verity471.models.location import Location
from verity471.models.malware import Malware
from verity471.models.malware_family import MalwareFamily
from verity471.models.malware_report_response import MalwareReportResponse
from verity471.models.malware_reports_response_stream import MalwareReportsResponseStream
from verity471.models.motivation import Motivation
from verity471.models.not_found import NotFound
from verity471.models.notification_preference_type import NotificationPreferenceType
from verity471.models.notification_settings_response import NotificationSettingsResponse
from verity471.models.observable import Observable
from verity471.models.observable_stream_page import ObservableStreamPage
from verity471.models.observable_type import ObservableType
from verity471.models.patch_status import PatchStatus
from verity471.models.poc import Poc
from verity471.models.post_details1 import PostDetails1
from verity471.models.post_response1 import PostResponse1
from verity471.models.private_message_details1 import PrivateMessageDetails1
from verity471.models.private_message_response1 import PrivateMessageResponse1
from verity471.models.processing_status import ProcessingStatus
from verity471.models.recipient_domain import RecipientDomain
from verity471.models.redirect import Redirect
from verity471.models.report import Report
from verity471.models.report_attachment import ReportAttachment
from verity471.models.report_content import ReportContent
from verity471.models.report_entities import ReportEntities
from verity471.models.report_location import ReportLocation
from verity471.models.report_observables import ReportObservables
from verity471.models.report_response_stream import ReportResponseStream
from verity471.models.report_type import ReportType
from verity471.models.reporting_status import ReportingStatus
from verity471.models.reports_victim_response import ReportsVictimResponse
from verity471.models.revocation import Revocation
from verity471.models.risk_level import RiskLevel
from verity471.models.room_stream import RoomStream
from verity471.models.security_assessment import SecurityAssessment
from verity471.models.server_stream import ServerStream
from verity471.models.settings import Settings
from verity471.models.share_settings_response import ShareSettingsResponse
from verity471.models.significant_activity import SignificantActivity
from verity471.models.simplified_malware_profile import SimplifiedMalwareProfile
from verity471.models.source_link import SourceLink
from verity471.models.source_links import SourceLinks
from verity471.models.sources_links import SourcesLinks
from verity471.models.sources_response import SourcesResponse
from verity471.models.spot_report_response import SpotReportResponse
from verity471.models.spot_reports_response_stream import SpotReportsResponseStream
from verity471.models.streaming_alerts_response import StreamingAlertsResponse
from verity471.models.streaming_watcher_alert import StreamingWatcherAlert
from verity471.models.sub_forum_response1 import SubForumResponse1
from verity471.models.template import Template
from verity471.models.tension_point_response import TensionPointResponse
from verity471.models.thread_response1 import ThreadResponse1
from verity471.models.threat import Threat
from verity471.models.threat_data import ThreatData
from verity471.models.threat_info import ThreatInfo
from verity471.models.threat_rating import ThreatRating
from verity471.models.translation_status import TranslationStatus
from verity471.models.trigger import Trigger
from verity471.models.unauthorized import Unauthorized
from verity471.models.victim_response import VictimResponse
from verity471.models.vulnerabilities_report_details_response import VulnerabilitiesReportDetailsResponse
from verity471.models.vulnerabilities_report_details_response_stream import VulnerabilitiesReportDetailsResponseStream
from verity471.models.vulnerabilities_reports_response_stream import VulnerabilitiesReportsResponseStream
from verity471.models.vulnerability_status import VulnerabilityStatus
from verity471.models.watcher_group_type import WatcherGroupType
from verity471.models.yara_data import YaraData

