# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from verity471.models.streaming_alerts_response import StreamingAlertsResponse

from verity471.api_client import ApiClient, RequestSerialized
from verity471.api_response import ApiResponse
from verity471.rest import RESTResponseType


class AlertsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_alerts_stream(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="Cursor to be used to fetch next batch from stream")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        watcher_group_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher group ids to filter alerts.")] = None,
        watcher_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher ids to filter alerts.")] = None,
        statuses: Annotated[Optional[StrictStr], Field(description="Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.")] = None,
        is_trashed_included: Annotated[Optional[StrictBool], Field(description="Include trashed alerts in the response. Defaults to false.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> StreamingAlertsResponse:
        """Get alerts for the current user in a stream way


        :param cursor: Cursor to be used to fetch next batch from stream
        :type cursor: str
        :param size: Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)
        :type size: int
        :param var_from: Long unix time. Example - 1627776000000 (By timestamp)
        :type var_from: int
        :param until: Long unix time. Example - 1627776000000 (By timestamp)
        :type until: int
        :param watcher_group_ids: Comma separated watcher group ids to filter alerts.
        :type watcher_group_ids: str
        :param watcher_ids: Comma separated watcher ids to filter alerts.
        :type watcher_ids: str
        :param statuses: Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.
        :type statuses: str
        :param is_trashed_included: Include trashed alerts in the response. Defaults to false.
        :type is_trashed_included: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_alerts_stream_serialize(
            cursor=cursor,
            size=size,
            var_from=var_from,
            until=until,
            watcher_group_ids=watcher_group_ids,
            watcher_ids=watcher_ids,
            statuses=statuses,
            is_trashed_included=is_trashed_included,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StreamingAlertsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_alerts_stream_with_http_info(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="Cursor to be used to fetch next batch from stream")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        watcher_group_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher group ids to filter alerts.")] = None,
        watcher_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher ids to filter alerts.")] = None,
        statuses: Annotated[Optional[StrictStr], Field(description="Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.")] = None,
        is_trashed_included: Annotated[Optional[StrictBool], Field(description="Include trashed alerts in the response. Defaults to false.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[StreamingAlertsResponse]:
        """Get alerts for the current user in a stream way


        :param cursor: Cursor to be used to fetch next batch from stream
        :type cursor: str
        :param size: Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)
        :type size: int
        :param var_from: Long unix time. Example - 1627776000000 (By timestamp)
        :type var_from: int
        :param until: Long unix time. Example - 1627776000000 (By timestamp)
        :type until: int
        :param watcher_group_ids: Comma separated watcher group ids to filter alerts.
        :type watcher_group_ids: str
        :param watcher_ids: Comma separated watcher ids to filter alerts.
        :type watcher_ids: str
        :param statuses: Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.
        :type statuses: str
        :param is_trashed_included: Include trashed alerts in the response. Defaults to false.
        :type is_trashed_included: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_alerts_stream_serialize(
            cursor=cursor,
            size=size,
            var_from=var_from,
            until=until,
            watcher_group_ids=watcher_group_ids,
            watcher_ids=watcher_ids,
            statuses=statuses,
            is_trashed_included=is_trashed_included,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StreamingAlertsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_alerts_stream_without_preload_content(
        self,
        cursor: Annotated[Optional[StrictStr], Field(description="Cursor to be used to fetch next batch from stream")] = None,
        size: Annotated[Optional[StrictInt], Field(description="Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix time. Example - 1627776000000 (By timestamp)")] = None,
        watcher_group_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher group ids to filter alerts.")] = None,
        watcher_ids: Annotated[Optional[StrictStr], Field(description="Comma separated watcher ids to filter alerts.")] = None,
        statuses: Annotated[Optional[StrictStr], Field(description="Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.")] = None,
        is_trashed_included: Annotated[Optional[StrictBool], Field(description="Include trashed alerts in the response. Defaults to false.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get alerts for the current user in a stream way


        :param cursor: Cursor to be used to fetch next batch from stream
        :type cursor: str
        :param size: Size of the batch to return. Defaults to 1000. Max value 1000 (if size is bigger than this onlyfirst 1000 alerts will be returned)
        :type size: int
        :param var_from: Long unix time. Example - 1627776000000 (By timestamp)
        :type var_from: int
        :param until: Long unix time. Example - 1627776000000 (By timestamp)
        :type until: int
        :param watcher_group_ids: Comma separated watcher group ids to filter alerts.
        :type watcher_group_ids: str
        :param watcher_ids: Comma separated watcher ids to filter alerts.
        :type watcher_ids: str
        :param statuses: Comma separated statuses to filter alerts. Allowed values are generated, needs_action, in_progress, completed and false_positive.
        :type statuses: str
        :param is_trashed_included: Include trashed alerts in the response. Defaults to false.
        :type is_trashed_included: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_alerts_stream_serialize(
            cursor=cursor,
            size=size,
            var_from=var_from,
            until=until,
            watcher_group_ids=watcher_group_ids,
            watcher_ids=watcher_ids,
            statuses=statuses,
            is_trashed_included=is_trashed_included,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StreamingAlertsResponse",
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_alerts_stream_serialize(
        self,
        cursor,
        size,
        var_from,
        until,
        watcher_group_ids,
        watcher_ids,
        statuses,
        is_trashed_included,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        if watcher_group_ids is not None:
            
            _query_params.append(('watcher_group_ids', watcher_group_ids))
            
        if watcher_ids is not None:
            
            _query_params.append(('watcher_ids', watcher_ids))
            
        if statuses is not None:
            
            _query_params.append(('statuses', statuses))
            
        if is_trashed_included is not None:
            
            _query_params.append(('is_trashed_included', is_trashed_included))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/watchers/v1/alerts/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def put_alerts_id_status(
        self,
        id: StrictInt,
        status: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Change status of an alert


        :param id: (required)
        :type id: int
        :param status: (required)
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_alerts_id_status_serialize(
            id=id,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def put_alerts_id_status_with_http_info(
        self,
        id: StrictInt,
        status: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Change status of an alert


        :param id: (required)
        :type id: int
        :param status: (required)
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_alerts_id_status_serialize(
            id=id,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def put_alerts_id_status_without_preload_content(
        self,
        id: StrictInt,
        status: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Change status of an alert


        :param id: (required)
        :type id: int
        :param status: (required)
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_alerts_id_status_serialize(
            id=id,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequest",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "NotFound",
            '409': "Conflict",
            '500': "InternalServerError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _put_alerts_id_status_serialize(
        self,
        id,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if status is not None:
            _path_params['status'] = status
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/integrations/watchers/v1/alerts/{id}/{status}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


