# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class EntityType(str, Enum):
    """
    EntityType
    """

    """
    allowed enum values
    """
    AIM = 'AIM'
    ACTORDOMAIN = 'ActorDomain'
    BITCOINADDRESS = 'BitcoinAddress'
    BITCOINTRANSACTIONID = 'BitcoinTransactionID'
    CVEID = 'CveID'
    OTHERCRYPTOCURRENCIES = 'OtherCryptoCurrencies'
    EMAILADDRESS = 'EmailAddress'
    FACEBOOK = 'Facebook'
    HANDLE = 'Handle'
    ICQ = 'ICQ'
    IPV4PREFIX = 'IPv4Prefix'
    IPV6PREFIX = 'IPv6Prefix'
    JABBER = 'Jabber'
    MSN = 'MSN'
    MALWAREFAMILY = 'MalwareFamily'
    MOBILEMALWAREFAMILY = 'MobileMalwareFamily'
    PERFECTMONEYID = 'PerfectMoneyID'
    PHONE = 'Phone'
    QQ = 'QQ'
    QIWIWALLET = 'QiwiWallet'
    SKYPE = 'Skype'
    TWITTER = 'Twitter'
    X = 'X'
    URL = 'URL'
    VK = 'VK'
    WEBMONEYID = 'WebMoneyID'
    WEBMONEYPURSE = 'WebMoneyPurse'
    YAHOOIM = 'YahooIM'
    YANDEXMONEY = 'YandexMoney'
    TELEGRAM = 'Telegram'
    TAG = 'Tag'
    TOX = 'Tox'
    PASSWORDHASH = 'PasswordHash'
    PASSWORD = 'Password'
    PGPKEY = 'PGPKey'
    PGPKEYID = 'PGPKeyID'
    ACTOROTHERWEBSITE = 'ActorOtherWebsite'
    ODNOKLASSNIKI = 'Odnoklassniki'
    MOIMIR = 'MoiMir'
    INSTAGRAM = 'Instagram'
    LINKEDIN = 'LinkedIn'
    GITHUB = 'GitHub'
    DISCORD = 'Discord'
    WECHAT = 'WeChat'
    WICKR = 'Wickr'
    SIGNAL = 'Signal'
    IPADDRESS = 'IPAddress'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of EntityType from a JSON string"""
        return cls(json.loads(json_str))


