# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ReportType(str, Enum):
    """
    Type of the related report
    """

    """
    allowed enum values
    """
    FINTEL = 'fintel'
    INFO_REPORT = 'info_report'
    BREACH_ALERT = 'breach_alert'
    SPOT_REPORT = 'spot_report'
    VULNERABILITY_REPORT = 'vulnerability_report'
    MALWARE_REPORT = 'malware_report'
    GEOPOL_REPORT = 'geopol_report'
    SITUATION_REPORT = 'situation_report'
    NEWS_REPORT = 'news_report'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ReportType from a JSON string"""
        return cls(json.loads(json_str))


