# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from verity471.models.geopol_report_details_response import GeopolReportDetailsResponse
from typing import Optional, Set, TYPE_CHECKING
from typing_extensions import Self

if TYPE_CHECKING:
    # Only for type checkers; does not run at runtime.
    from verity471.verity_stix import STIXMapperSettings


class GeopolReportsResponseStream(BaseModel):
    """
    GeopolReportsResponseStream
    """ # noqa: E501
    adversary_profile_count: StrictInt = Field(description="Count of Adversary Profile reports")
    count: StrictInt = Field(description="Number of total Geopol reports matching the query")
    cursor_next: Optional[StrictStr] = Field(default=None, description="Stream position identifier to continue scrolling from")
    intelligence_bulletin_count: StrictInt = Field(description="Count of Intelligence Bulletin reports")
    intelligence_estimate_count: StrictInt = Field(description="Count of Intelligence Estimate reports")
    intelligence_summary_count: StrictInt = Field(description="Count of Intelligence Summary reports")
    reports: Optional[List[GeopolReportDetailsResponse]] = Field(default=None, description="List of Geopol reports in the current batch")
    sigact_count: StrictInt = Field(description="Count of Significant Activity Report reports")
    spot_count: StrictInt = Field(description="Count of Geopol Spot Report reports")
    tension_point_profile_count: StrictInt = Field(description="Count of Tension Point Profile reports")
    threat_brief_count: StrictInt = Field(description="Count of Threat Brief reports")
    __properties: ClassVar[List[str]] = ["adversary_profile_count", "count", "cursor_next", "intelligence_bulletin_count", "intelligence_estimate_count", "intelligence_summary_count", "reports", "sigact_count", "spot_count", "tension_point_profile_count", "threat_brief_count"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_stix(self, settings: Optional["STIXMapperSettings"] = None):
        try:
            from verity471.verity_stix.mappers.common import StixMapper
        except ImportError as e:
            raise ImportError(
                "STIX support is an optional feature. "
                "Install with: pip install 'verity471[stix]'"
            ) from e
        stix_mapper = StixMapper(settings)
        return stix_mapper.map(self.to_dict())

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GeopolReportsResponseStream from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in reports (list)
        _items = []
        if self.reports:
            for _item_reports in self.reports:
                if _item_reports:
                    _items.append(_item_reports.to_dict())
            _dict['reports'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GeopolReportsResponseStream from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "adversary_profile_count": obj.get("adversary_profile_count"),
            "count": obj.get("count"),
            "cursor_next": obj.get("cursor_next"),
            "intelligence_bulletin_count": obj.get("intelligence_bulletin_count"),
            "intelligence_estimate_count": obj.get("intelligence_estimate_count"),
            "intelligence_summary_count": obj.get("intelligence_summary_count"),
            "reports": [GeopolReportDetailsResponse.from_dict(_item) for _item in obj["reports"]] if obj.get("reports") is not None else None,
            "sigact_count": obj.get("sigact_count"),
            "spot_count": obj.get("spot_count"),
            "tension_point_profile_count": obj.get("tension_point_profile_count"),
            "threat_brief_count": obj.get("threat_brief_count")
        })
        return _obj


