# coding: utf-8

"""
    Verity471 Unified API

      - creds: 1.0.1
  - indicators: 1.0.0
  - malware: 1.0.0
  - reports: 1.0.0
  - sources: 1.0.2
  - actors: 1.0.1
  - watchers: 1.0.0
  - observables: 1.0.0
  - entities: 1.0.0
  - girs: 1.0.0


    The version of the OpenAPI document: 1.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from verity471.models.indicators_stream import IndicatorsStream
from verity471.models.integrations_indicator import IntegrationsIndicator

from verity471.api_client import ApiClient, RequestSerialized
from verity471.api_response import ApiResponse
from verity471.rest import RESTResponseType


class IndicatorsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_indicator_by_id(
        self,
        id: Annotated[StrictStr, Field(description="Id of the indicator")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> IntegrationsIndicator:
        """Get indicator by id


        :param id: Id of the indicator (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indicator_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IntegrationsIndicator",
            '400': "ErrorResponse",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_indicator_by_id_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Id of the indicator")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[IntegrationsIndicator]:
        """Get indicator by id


        :param id: Id of the indicator (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indicator_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IntegrationsIndicator",
            '400': "ErrorResponse",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_indicator_by_id_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Id of the indicator")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get indicator by id


        :param id: Id of the indicator (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indicator_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IntegrationsIndicator",
            '400': "ErrorResponse",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_indicator_by_id_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/indicators/v1/indicators/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_indicators_stream(
        self,
        type: Annotated[Optional[StrictStr], Field(description="Search indicators by type")] = None,
        threat_type: Annotated[Optional[StrictStr], Field(description="Search indicators by threat type")] = None,
        confidence: Annotated[Optional[StrictStr], Field(description="Search indicators by confidence")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Free text indicator search (all fields included)")] = None,
        malware_id: Annotated[Optional[StrictStr], Field(description="Search indicators by malware id")] = None,
        malware_family_id: Annotated[Optional[StrictStr], Field(description="Search indicators by malware family id")] = None,
        malware_family_name: Annotated[Optional[StrictStr], Field(description="Search indicators by malware family")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list")] = None,
        size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The size of the page to be returned. Max size: `1000`")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix timestamp in milliseconds. Search data starting from given `activity.first_seen_ts` and `activity.last_seen_ts` (including). Example - `1627776000000`")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix timestamp in milliseconds. Search data ending before given `activity.first_seen_ts` and `activity.last_seen_ts` (excluding). Example - `1627776000000`")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> IndicatorsStream:
        """Stream indicators using a cursor

        Indicators sorted in ascending order of processed time.

        :param type: Search indicators by type
        :type type: str
        :param threat_type: Search indicators by threat type
        :type threat_type: str
        :param confidence: Search indicators by confidence
        :type confidence: str
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param text_filter: Free text indicator search (all fields included)
        :type text_filter: str
        :param malware_id: Search indicators by malware id
        :type malware_id: str
        :param malware_family_id: Search indicators by malware family id
        :type malware_family_id: str
        :param malware_family_name: Search indicators by malware family
        :type malware_family_name: str
        :param girs: Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param size: The size of the page to be returned. Max size: `1000`
        :type size: int
        :param var_from: Long unix timestamp in milliseconds. Search data starting from given `activity.first_seen_ts` and `activity.last_seen_ts` (including). Example - `1627776000000`
        :type var_from: int
        :param until: Long unix timestamp in milliseconds. Search data ending before given `activity.first_seen_ts` and `activity.last_seen_ts` (excluding). Example - `1627776000000`
        :type until: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indicators_stream_serialize(
            type=type,
            threat_type=threat_type,
            confidence=confidence,
            cursor=cursor,
            text_filter=text_filter,
            malware_id=malware_id,
            malware_family_id=malware_family_id,
            malware_family_name=malware_family_name,
            girs=girs,
            size=size,
            var_from=var_from,
            until=until,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IndicatorsStream",
            '400': "ErrorResponse",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_indicators_stream_with_http_info(
        self,
        type: Annotated[Optional[StrictStr], Field(description="Search indicators by type")] = None,
        threat_type: Annotated[Optional[StrictStr], Field(description="Search indicators by threat type")] = None,
        confidence: Annotated[Optional[StrictStr], Field(description="Search indicators by confidence")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Free text indicator search (all fields included)")] = None,
        malware_id: Annotated[Optional[StrictStr], Field(description="Search indicators by malware id")] = None,
        malware_family_id: Annotated[Optional[StrictStr], Field(description="Search indicators by malware family id")] = None,
        malware_family_name: Annotated[Optional[StrictStr], Field(description="Search indicators by malware family")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list")] = None,
        size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The size of the page to be returned. Max size: `1000`")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix timestamp in milliseconds. Search data starting from given `activity.first_seen_ts` and `activity.last_seen_ts` (including). Example - `1627776000000`")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix timestamp in milliseconds. Search data ending before given `activity.first_seen_ts` and `activity.last_seen_ts` (excluding). Example - `1627776000000`")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[IndicatorsStream]:
        """Stream indicators using a cursor

        Indicators sorted in ascending order of processed time.

        :param type: Search indicators by type
        :type type: str
        :param threat_type: Search indicators by threat type
        :type threat_type: str
        :param confidence: Search indicators by confidence
        :type confidence: str
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param text_filter: Free text indicator search (all fields included)
        :type text_filter: str
        :param malware_id: Search indicators by malware id
        :type malware_id: str
        :param malware_family_id: Search indicators by malware family id
        :type malware_family_id: str
        :param malware_family_name: Search indicators by malware family
        :type malware_family_name: str
        :param girs: Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param size: The size of the page to be returned. Max size: `1000`
        :type size: int
        :param var_from: Long unix timestamp in milliseconds. Search data starting from given `activity.first_seen_ts` and `activity.last_seen_ts` (including). Example - `1627776000000`
        :type var_from: int
        :param until: Long unix timestamp in milliseconds. Search data ending before given `activity.first_seen_ts` and `activity.last_seen_ts` (excluding). Example - `1627776000000`
        :type until: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indicators_stream_serialize(
            type=type,
            threat_type=threat_type,
            confidence=confidence,
            cursor=cursor,
            text_filter=text_filter,
            malware_id=malware_id,
            malware_family_id=malware_family_id,
            malware_family_name=malware_family_name,
            girs=girs,
            size=size,
            var_from=var_from,
            until=until,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IndicatorsStream",
            '400': "ErrorResponse",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_indicators_stream_without_preload_content(
        self,
        type: Annotated[Optional[StrictStr], Field(description="Search indicators by type")] = None,
        threat_type: Annotated[Optional[StrictStr], Field(description="Search indicators by threat type")] = None,
        confidence: Annotated[Optional[StrictStr], Field(description="Search indicators by confidence")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Continue scrolling from cursor")] = None,
        text_filter: Annotated[Optional[StrictStr], Field(description="Free text indicator search (all fields included)")] = None,
        malware_id: Annotated[Optional[StrictStr], Field(description="Search indicators by malware id")] = None,
        malware_family_id: Annotated[Optional[StrictStr], Field(description="Search indicators by malware family id")] = None,
        malware_family_name: Annotated[Optional[StrictStr], Field(description="Search indicators by malware family")] = None,
        girs: Annotated[Optional[StrictStr], Field(description="Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list")] = None,
        size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The size of the page to be returned. Max size: `1000`")] = None,
        var_from: Annotated[Optional[StrictInt], Field(description="Long unix timestamp in milliseconds. Search data starting from given `activity.first_seen_ts` and `activity.last_seen_ts` (including). Example - `1627776000000`")] = None,
        until: Annotated[Optional[StrictInt], Field(description="Long unix timestamp in milliseconds. Search data ending before given `activity.first_seen_ts` and `activity.last_seen_ts` (excluding). Example - `1627776000000`")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Stream indicators using a cursor

        Indicators sorted in ascending order of processed time.

        :param type: Search indicators by type
        :type type: str
        :param threat_type: Search indicators by threat type
        :type threat_type: str
        :param confidence: Search indicators by confidence
        :type confidence: str
        :param cursor: Continue scrolling from cursor
        :type cursor: str
        :param text_filter: Free text indicator search (all fields included)
        :type text_filter: str
        :param malware_id: Search indicators by malware id
        :type malware_id: str
        :param malware_family_id: Search indicators by malware family id
        :type malware_family_id: str
        :param malware_family_name: Search indicators by malware family
        :type malware_family_name: str
        :param girs: Filter result by custom GIRs (General intel requirements), `my_girs` or `company_pirs`. Using multiple value will return result based on the aggregated GIR list
        :type girs: str
        :param size: The size of the page to be returned. Max size: `1000`
        :type size: int
        :param var_from: Long unix timestamp in milliseconds. Search data starting from given `activity.first_seen_ts` and `activity.last_seen_ts` (including). Example - `1627776000000`
        :type var_from: int
        :param until: Long unix timestamp in milliseconds. Search data ending before given `activity.first_seen_ts` and `activity.last_seen_ts` (excluding). Example - `1627776000000`
        :type until: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_indicators_stream_serialize(
            type=type,
            threat_type=threat_type,
            confidence=confidence,
            cursor=cursor,
            text_filter=text_filter,
            malware_id=malware_id,
            malware_family_id=malware_family_id,
            malware_family_name=malware_family_name,
            girs=girs,
            size=size,
            var_from=var_from,
            until=until,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IndicatorsStream",
            '400': "ErrorResponse",
            '401': "Unauthorized",
            '403': "Forbidden",
            '404': "ErrorResponse",
            '500': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_indicators_stream_serialize(
        self,
        type,
        threat_type,
        confidence,
        cursor,
        text_filter,
        malware_id,
        malware_family_id,
        malware_family_name,
        girs,
        size,
        var_from,
        until,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if type is not None:
            
            _query_params.append(('type', type))
            
        if threat_type is not None:
            
            _query_params.append(('threat_type', threat_type))
            
        if confidence is not None:
            
            _query_params.append(('confidence', confidence))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if text_filter is not None:
            
            _query_params.append(('text_filter', text_filter))
            
        if malware_id is not None:
            
            _query_params.append(('malware_id', malware_id))
            
        if malware_family_id is not None:
            
            _query_params.append(('malware_family_id', malware_family_id))
            
        if malware_family_name is not None:
            
            _query_params.append(('malware_family_name', malware_family_name))
            
        if girs is not None:
            
            _query_params.append(('girs', girs))
            
        if size is not None:
            
            _query_params.append(('size', size))
            
        if var_from is not None:
            
            _query_params.append(('from', var_from))
            
        if until is not None:
            
            _query_params.append(('until', until))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'basicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/integrations/indicators/v1/indicators/stream',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


